@@ -164,11 +164,11 @@ class Server(object):
         diff = now - self._last_tick
         self._last_tick = now
         if diff > tick_maximum_delay:
-            logger.warning("Event loop was unresponsive in %s for %.2fs.  "
-                           "This is often caused by long-running GIL-holding "
-                           "functions or moving large chunks of data. "
-                           "This can cause timeouts and instability.",
-                           type(self).__name__, diff)
+            logger.info("Event loop was unresponsive in %s for %.2fs.  "
+                        "This is often caused by long-running GIL-holding "
+                        "functions or moving large chunks of data. "
+                        "This can cause timeouts and instability.",
+                        type(self).__name__, diff)
         if self.digests is not None:
             self.digests['tick-duration'].add(diff)
 
@@ -286,8 +286,8 @@ class Server(object):
                 try:
                     handler = self.handlers[op]
                 except KeyError:
-                    result = "No handler found: %s" % op
-                    logger.warning(result, exc_info=True)
+                    logger.warning("No handler %s found in %s", op,
+                                   type(self).__name__, exc_info=True)
                 else:
                     logger.debug("Calling into handler %s", handler.__name__)
                     try:
@@ -296,7 +296,8 @@ class Server(object):
                             self._ongoing_coroutines.add(result)
                             result = yield result
                     except (CommClosedError, CancelledError) as e:
-                        logger.warning("Lost connection to %r: %s", address, e)
+                        if self.status == 'running':
+                            logger.info("Lost connection to %r: %s", address, e)
                         break
                     except Exception as e:
                         logger.exception(e)
